from textual.app import App, ComposeResult
from textual.widgets import Static, Button, Input


class SimpleApp(App):
    CSS = "Screen { layout: vertical; }"

    def compose(self) -> ComposeResult:
        yield Static("Hello World", id="greeting")
        yield Input(placeholder="Type here...", id="text-input")
        yield Button("Click Me", id="btn", variant="primary")
