from textual.app import App, ComposeResult
from textual.widgets import Button


class ErrorApp(App):
    def compose(self) -> ComposeResult:
        yield Button("Crash", id="crash-btn")

    def on_button_pressed(self, event: Button.Pressed) -> None:
        raise RuntimeError("Intentional crash")
