"""Module with no App subclass — used for testing error handling."""


class NotAnApp:
    """A regular class, not a Textual App."""

    def run(self):
        pass


def helper_function():
    return "I'm just a helper"
